import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 960;
const height = 500;

const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;

const eyeRadius = 40;
const eyeOffsetX = 80;
const eyeOffsetY = 100;
const mouthWidth = 30;
const mouthRadius = 140;

const HeadCircle = ({ radius }) => (
  <circle 
    r={radius}
    fill="yellow"
    stroke="black"
    stroke-width={strokeWidth}
  />
);

const Eye = ({ eyeOffsetX, eyeOffsetY }) => (
  <circle 
    cx={eyeOffsetX}
    cy={eyeOffsetY}
    r={eyeRadius}
  />
)

const mouthArc = arc()
  .innerRadius(mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI / 2)
  .endAngle(Math.PI * 3 / 2);

const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      <HeadCircle radius={centerY - strokeWidth / 2}/>      
      // Left Eye
      <Eye eyeOffsetX={-eyeOffsetX} eyeOffsetY={-eyeOffsetY} />
      // Right Eye
      <Eye eyeOffsetX={eyeOffsetX} eyeOffsetY={-eyeOffsetY} />
      // Mouth
      <path d={mouthArc()}/>
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);